==> owncloud-4.5.0.tar.bz2: owncloud/apps/contacts/l10n/da.php <==
<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "Fejl ved (de)aktivering af adressebogen",
"id is not set." => "Intet ID medsendt.",
"Cannot update addressbook with an empty name." => "Kan ikke opdatére adressebogen med et tomt navn.",
"No ID provided" => "Intet ID medsendt",
"Error setting checksum." => "Kunne ikke sætte checksum.",
"No categories selected for deletion." => "Der ikke valgt nogle grupper at slette.",
"No address books found." => "Der blev ikke fundet nogen adressebøger.",
"No contacts found." => "Der blev ikke fundet nogen kontaktpersoner.",
"element name is not set." => "Elementnavnet er ikke medsendt.",
"Could not parse contact: " => "Kunne ikke indlæse kontaktperson",
"Cannot add empty property." => "Kan ikke tilføje en egenskab uden indhold.",
"At least one of the address fields has to be filled out." => "Der skal udfyldes mindst et adressefelt.",
"Trying to add duplicate property: " => "Kan ikke tilføje overlappende element.",
"Missing IM parameter." => "Manglende IM parameter.",
"Unknown IM: " => "Ukendt IM:",
"Information about vCard is incorrect. Please reload the page." => "Informationen om vCard er forkert. Genindlæs siden.",
"Missing ID" => "Manglende ID",
"Error parsing VCard for ID: \"" => "Kunne ikke indlæse VCard med ID'et: \"",
"checksum is not set." => "Checksum er ikke medsendt.",
"Information about vCard is incorrect. Please reload the page: " => "Informationen om dette VCard stemmer ikke. Genindlæs venligst siden: ",
"Something went FUBAR. " => "Noget gik grueligt galt. ",
"No contact ID was submitted." => "Ingen ID for kontakperson medsendt.",
"Error reading contact photo." => "Kunne ikke indlæse foto for kontakperson.",
"Error saving temporary file." => "Kunne ikke gemme midlertidig fil.",
"The loading photo is not valid." => "Billedet under indlæsning er ikke gyldigt.",
"Contact ID is missing." => "Kontaktperson ID mangler.",
"No photo path was submitted." => "Der blev ikke medsendt en sti til fotoet.",
"File doesn't exist:" => "Filen eksisterer ikke:",
"Error loading image." => "Kunne ikke indlæse billede.",
"Error getting contact object." => "Fejl ved indlæsning af kontaktpersonobjektet.",
"Error getting PHOTO property." => "Fejl ved indlæsning af PHOTO feltet.",
"Error saving contact." => "Kunne ikke gemme kontaktpersonen.",
"Error resizing image" => "Kunne ikke ændre billedets størrelse",
"Error cropping image" => "Kunne ikke beskære billedet",
"Error creating temporary image" => "Kunne ikke oprette midlertidigt billede",
"Error finding image: " => "Kunne ikke finde billedet: ",
"Error uploading contacts to storage." => "Kunne ikke uploade kontaktepersoner til midlertidig opbevaring.",
"There is no error, the file uploaded with success" => "Der skete ingen fejl, filen blev succesfuldt uploadet",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Den uploadede fil er større end upload_max_filesize indstillingen i php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Den uploadede fil overstiger MAX_FILE_SIZE indstilingen, som specificeret i HTML formularen",
"The uploaded file was only partially uploaded" => "Filen blev kun delvist uploadet.",
"No file was uploaded" => "Ingen fil uploadet",
"Missing a temporary folder" => "Manglende midlertidig mappe.",
"Couldn't save temporary image: " => "Kunne ikke gemme midlertidigt billede: ",
"Couldn't load temporary image: " => "Kunne ikke indlæse midlertidigt billede",
"No file was uploaded. Unknown error" => "Ingen fil blev uploadet. Ukendt fejl.",
"Contacts" => "Kontaktpersoner",
"Sorry, this functionality has not been implemented yet" => "Denne funktion er desværre ikke implementeret endnu",
"Not implemented" => "Ikke implementeret",
"Couldn't get a valid address." => "Kunne ikke finde en gyldig adresse.",
"Error" => "Fejl",
"Enter name" => "Indtast navn",
"Format custom, Short name, Full name, Reverse or Reverse with comma" => "Formatter som valgfrit, fuldt navn, efternavn først eller efternavn først med komma",
"Select type" => "Vælg type",
"Select photo" => "Vælg foto",
"You do not have permission to add contacts to " => "Du har ikke rettigheder til at tilføje kontaktpersoner til ",
"Please select one of your own address books." => "Vælg venligst en af dine egne adressebøger.",
"Permission error" => "Manglende rettigheder",
"This property has to be non-empty." => "Dette felt må ikke være tomt.",
"Couldn't serialize elements." => "Kunne ikke serialisere elementerne.",
"'deleteProperty' called without type argument. Please report at bugs.owncloud.org" => "'deleteProperty' kaldet uden typeargument. Indrapporter fejl på bugs.owncloud.org",
"Edit name" => "Rediger navn",
"No files selected for upload." => "Der er ikke valgt nogen filer at uploade.",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "Dr.",
"Error loading profile picture." => "Fejl ved indlæsning af profilbillede",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Nogle kontakter er markeret til sletning, men er endnu ikke slettet. Vent venligst på, at de bliver slettet.",
"Do you want to merge these address books?" => "Vil du fusionere disse adressebøger?",
"Shared by " => "Delt af",
"Upload too large" => "Upload er for stor",
"Unable to upload your file as it is a directory or has 0 bytes" => "Kan ikke uploade din fil - det er enten en mappe eller en fil med et indhold på 0 bytes.",
"Upload Error" => "Fejl i upload",
"Pending" => "Afventer",
"Import done" => "Import fuldført",
"Not all files uploaded. Retrying..." => "Nogle filer blev ikke uploadet. Forsøger igen...",
"Something went wrong with the upload, please retry." => "Der opstod en fejl under upload. Forsøg igen.",
"Importing..." => "Importerer...",
"The address book name cannot be empty." => "Adressebogens navn kan ikke være tomt.",
"Result: " => "Resultat:",
" imported, " => " importeret ",
" failed." => " fejl.",
"Displayname cannot be empty." => "Brugernavn må ikke være tomt.",
"Show CardDav link" => "Vis CardDav link",
"Show read-only VCF link" => "Vis skrivebeskyttet VCF link",
"Download" => "Download",
"Edit" => "Rediger",
"Delete" => "Slet",
"Cancel" => "Fortryd",
"More..." => "Mere...",
"Less..." => "Mindre...",
"You do not have the permissions to read this addressbook." => "Du har ikke rettigheder til at se denne adressebog.",
"You do not have the permissions to update this addressbook." => "Du har ikke rettigheder til at opdatere denne adressebog",
"There was an error updating the addressbook." => "Du har ikke rettigheder til at opdatere denne kontaktperson",
"You do not have the permissions to delete this addressbook." => "Du har ikke rettigheder til at slette denne adressebog",
"There was an error deleting this addressbook." => "Der opstod en fejl ved sletning af denne adressebog.",
"Addressbook not found: " => "Adressebog ikke fundet:",
"This is not your addressbook." => "Dette er ikke din adressebog.",
"Contact could not be found." => "Kontaktperson kunne ikke findes.",
"Jabber" => "Jabber",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "Google Talk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "Arbejde",
"Home" => "Hjemme",
"Other" => "Andet",
"Mobile" => "Mobil",
"Text" => "SMS",
"Voice" => "Telefonsvarer",
"Message" => "Besked",
"Fax" => "Fax",
"Video" => "Video",
"Pager" => "Personsøger",
"Internet" => "Internet",
"Birthday" => "Fødselsdag",
"Business" => "Firma",
"Call" => "Ring op",
"Clients" => "Klienter",
"Deliverer" => "Udbringer",
"Holidays" => "Ferie",
"Ideas" => "Ideer",
"Journey" => "Rejse",
"Jubilee" => "Jubilæum",
"Meeting" => "Møde",
"Personal" => "Personligt",
"Projects" => "Projekter",
"Questions" => "Spørgsmål",
"{name}'s Birthday" => "{name}s fødselsdag",
"Contact" => "Kontaktperson",
"You do not have the permissions to add contacts to this addressbook." => "Du har ikke rettigheder til at tilføje kontaktpersoner til denne adressebog",
"Could not find the vCard with ID." => "Kunne ikke finde vCard'et med ID.",
"You do not have the permissions to edit this contact." => "Du har ikke rettigheder til at redigere denne kontaktperson",
"Could not find the vCard with ID: " => "Kunne ikke finde vCard'et med ID:",
"Could not find the Addressbook with ID: " => "Kunne ikke finde adressebogen med ID.",
"You do not have the permissions to delete this contact." => "Du har ikke rettigheder til at slette denne kontaktperson",
"There was an error deleting this contact." => "Der opstod en fejl ved sletning af denne kontakt.",
"Add Contact" => "Tilføj kontaktperson",
"Import" => "Importer",
"Settings" => "Indstillinger",
"Close" => "Luk",
"Keyboard shortcuts" => "Tastaturgenveje",
"Navigation" => "Navigering",
"Next contact in list" => "Næste kontaktperson i listen",
"Previous contact in list" => "Forrige kontaktperson i listen",
"Expand/collapse current addressbook" => "Udvid/sammenfold nuværende adressebog",
"Next addressbook" => "Næste adressebog",
"Previous addressbook" => "Forrige adressebog",
"Actions" => "Handlinger",
"Refresh contacts list" => "Genindlæs kontaktliste",
"Add new contact" => "Tilføj ny kontaktperson",
"Add new addressbook" => "Tilføj ny adressebog",
"Delete current contact" => "Slet aktuelle kontaktperson",
"Drop photo to upload" => "Drop foto for at uploade",
"Delete current photo" => "Slet nuværende foto",
"Edit current photo" => "Rediger nuværende foto",
"Upload new photo" => "Upload nyt foto",
"Select photo from ownCloud" => "Vælg foto fra ownCloud",
"Edit name details" => "Rediger navnedetaljer.",
"Organization" => "Organisation",
"Nickname" => "Kaldenavn",
"Enter nickname" => "Indtast kaldenavn",
"Web site" => "Hjemmeside",
"http://www.somesite.com" => "http://www.somesite.com",
"Go to web site" => "Gå til web site",
"dd-mm-yyyy" => "dd-mm-åååå",
"Groups" => "Grupper",
"Separate groups with commas" => "Opdel gruppenavne med kommaer",
"Edit groups" => "Rediger grupper",
"Preferred" => "Foretrukken",
"Please specify a valid email address." => "Indtast venligst en gyldig email-adresse.",
"Enter email address" => "Indtast email-adresse",
"Mail to address" => "Send mail til adresse",
"Delete email address" => "Slet email-adresse",
"Enter phone number" => "Indtast telefonnummer",
"Delete phone number" => "Slet telefonnummer",
"Instant Messenger" => "Instant Messenger",
"Delete IM" => "Slet IM",
"View on map" => "Vis på kort",
"Edit address details" => "Rediger adresse detaljer",
"Add notes here." => "Tilføj noter her.",
"Add field" => "Tilføj element",
"Phone" => "Telefon",
"Email" => "Email",
"Instant Messaging" => "Instant Messaging",
"Address" => "Adresse",
"Note" => "Note",
"Download contact" => "Download kontaktperson",
"Delete contact" => "Slet kontaktperson",
"The temporary image has been removed from cache." => "Det midlertidige billede er ikke længere tilgængeligt.",
"Edit address" => "Rediger adresse",
"Type" => "Type",
"PO Box" => "Postboks",
"Street address" => "Gade",
"Street and number" => "Gade og nummer",
"Extended" => "Udvidet",
"Apartment number etc." => "Etage, side osv.",
"City" => "By",
"Region" => "Region",
"E.g. state or province" => "F.eks. stat eller provins",
"Zipcode" => "Postnummer",
"Postal code" => "Postnummer",
"Country" => "Land",
"Addressbook" => "Adressebog",
"Hon. prefixes" => "Foranstillede titler",
"Miss" => "Frøken",
"Ms" => "Fru",
"Mr" => "Hr.",
"Sir" => "Sir",
"Mrs" => "Fru",
"Dr" => "Dr.",
"Given name" => "Fornavn",
"Additional names" => "Mellemnavne",
"Family name" => "Efternavn",
"Hon. suffixes" => "Efterstillede titler",
"J.D." => "Cand. Jur.",
"M.D." => "M.D.",
"D.O." => "D.O.",
"D.C." => "D.C.",
"Ph.D." => "Ph.D.",
"Esq." => "Esq.",
"Jr." => "Jr.",
"Sn." => "Sn.",
"Import a contacts file" => "Importer fil med kontaktpersoner",
"Please choose the addressbook" => "Vælg venligst adressebog",
"create a new addressbook" => "Opret ny adressebog",
"Name of new addressbook" => "Navn på ny adressebog",
"Importing contacts" => "Importerer kontaktpersoner",
"<h3>You have no contacts in your addressbook.</h3><p>You can import VCF files by dragging them to the contacts list and either drop them on an addressbook to import into it, or on an empty spot to create a new addressbook and import into that.<br />You can also import by clicking on the import button at the bottom of the list.</p>" => "<h3>Du har ingen kontakter i din adressebog.</h3><p>Du kan importere VCF-filer ved at trække dem gil kontaktlisten og enten slippe dem på en adressebog for at importere ind i den eller udenfor listen for at oprette en ny med kontaktoplysningerne fra filen.<br />Du kan også importere ved at klikke på importknappen under listen.</p>",
"Add contact" => "Tilføj kontaktpeson.",
"Select Address Books" => "Vælg adressebog",
"Enter description" => "Indtast beskrivelse",
"CardDAV syncing addresses" => "CardDAV synkroniserings adresse",
"more info" => "mere info",
"Primary address (Kontact et al)" => "Primær adresse (Kontak m. fl.)",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Adressebøger",
"Share" => "Del",
"New Address Book" => "Ny adressebog",
"Name" => "Navn",
"Description" => "Beskrivelse",
"Save" => "Gem"
);

==> owncloud-5.0.17.tar.bz2: owncloud/apps/contacts/l10n/da.php <==
<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "Fejl ved (de)aktivering af adressebogen",
"id is not set." => "Intet ID medsendt.",
"Cannot update addressbook with an empty name." => "Kan ikke opdatére adressebogen med et tomt navn.",
"No category name given." => "Ingen kategori navn givet.",
"Error adding group." => "Fejl ved tilføjelse af gruppe.",
"Group ID missing from request." => "Group ID mangler anmodning.",
"Contact ID missing from request." => "Kontakt ID mangler anmodning.",
"No ID provided" => "Intet ID medsendt",
"Error setting checksum." => "Kunne ikke sætte checksum.",
"No categories selected for deletion." => "Der ikke valgt nogle grupper at slette.",
"No address books found." => "Der blev ikke fundet nogen adressebøger.",
"No contacts found." => "Der blev ikke fundet nogen kontaktpersoner.",
"element name is not set." => "Elementnavnet er ikke medsendt.",
"checksum is not set." => "Checksum er ikke medsendt.",
"Information about vCard is incorrect. Please reload the page." => "Informationen om vCard er forkert. Genindlæs siden.",
"Couldn't find vCard for %d." => "Kunne ikke finde vCard for %d.",
"Information about vCard is incorrect. Please reload the page: " => "Informationen om dette VCard stemmer ikke. Genindlæs venligst siden: ",
"Something went FUBAR. " => "Noget gik grueligt galt. ",
"Cannot save property of type \"%s\" as array" => "Kan ikke gemme egenskab af typen \"%s\" som array",
"Missing IM parameter." => "Manglende IM parameter.",
"Unknown IM: " => "Ukendt IM:",
"No contact ID was submitted." => "Ingen ID for kontakperson medsendt.",
"Error reading contact photo." => "Kunne ikke indlæse foto for kontakperson.",
"Error saving temporary file." => "Kunne ikke gemme midlertidig fil.",
"The loading photo is not valid." => "Billedet under indlæsning er ikke gyldigt.",
"Contact ID is missing." => "Kontaktperson ID mangler.",
"No photo path was submitted." => "Der blev ikke medsendt en sti til fotoet.",
"File doesn't exist:" => "Filen eksisterer ikke:",
"Error loading image." => "Kunne ikke indlæse billede.",
"Error getting contact object." => "Fejl ved indlæsning af kontaktpersonobjektet.",
"Error getting PHOTO property." => "Fejl ved indlæsning af PHOTO feltet.",
"Error saving contact." => "Kunne ikke gemme kontaktpersonen.",
"Error resizing image" => "Kunne ikke ændre billedets størrelse",
"Error cropping image" => "Kunne ikke beskære billedet",
"Error creating temporary image" => "Kunne ikke oprette midlertidigt billede",
"Error finding image: " => "Kunne ikke finde billedet: ",
"Key is not set for: " => "Nøgle er ikke indstillet til:",
"Value is not set for: " => "Value er ikke indstillet til:",
"Could not set preference: " => "Kunne ikke sætte præference:",
"Error uploading contacts to storage." => "Kunne ikke uploade kontaktepersoner til midlertidig opbevaring.",
"There is no error, the file uploaded with success" => "Der skete ingen fejl, filen blev succesfuldt uploadet",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Den uploadede fil er større end upload_max_filesize indstillingen i php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Den uploadede fil overstiger MAX_FILE_SIZE indstilingen, som specificeret i HTML formularen",
"The uploaded file was only partially uploaded" => "Filen blev kun delvist uploadet.",
"No file was uploaded" => "Ingen fil uploadet",
"Missing a temporary folder" => "Manglende midlertidig mappe.",
"Couldn't save temporary image: " => "Kunne ikke gemme midlertidigt billede: ",
"Couldn't load temporary image: " => "Kunne ikke indlæse midlertidigt billede",
"No file was uploaded. Unknown error" => "Ingen fil blev uploadet. Ukendt fejl.",
"Contacts" => "Kontaktpersoner",
"%d_selected_contacts" => "%d_selected_contacts",
"Add to..." => "Føj til...",
"Remove from..." => "Fjern fra...",
"Add group..." => "Tilføj gruppe...",
"Indexing contacts" => "Indeksering kontakter",
"Select photo" => "Vælg foto",
"Network or server error. Please inform administrator." => "Netværk eller serverfejl. Informer venligst administratoren.",
"Error adding to group." => "Fejl ved tilføjelse til gruppen.",
"Error removing from group." => "Fejl ved fjernelse af gruppen.",
"There was an error opening a mail composer." => "Der opstod en fejl under åbning af en e-mail klient.",
"Deleting done. Click here to cancel reloading." => "Sletning udføres. Klik her for at annullere genindlæsningen.",
"Add address book" => "Tilføj adressebog",
"Import done. Click here to cancel reloading." => "Import gjort. Klik her for at annullere genindlæsning.",
"Not all files uploaded. Retrying..." => "Nogle filer blev ikke uploadet. Forsøger igen...",
"Something went wrong with the upload, please retry." => "Der opstod en fejl under upload. Forsøg igen.",
"Error" => "Fejl",
"Importing from {filename}..." => "Importing from {filename}...",
"{success} imported, {failed} failed." => "{success} importeret, {failed} mislykkedes.",
"Importing..." => "Importerer...",
"Unable to upload your file as it is a directory or has 0 bytes" => "Kan ikke uploade din fil - det er enten en mappe eller en fil med et indhold på 0 bytes.",
"Upload Error" => "Fejl i upload",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "Dr.",
"Upload too large" => "Upload er for stor",
"Pending" => "Afventer",
"Add group" => "Tilføj gruppe",
"No files selected for upload." => "Der er ikke valgt nogen filer at uploade.",
"Edit profile picture" => "Rediger profil billede",
"Error loading profile picture." => "Fejl ved indlæsning af profilbillede",
"Enter name" => "Indtast navn",
"Enter description" => "Indtast beskrivelse",
"Select addressbook" => "Vælg adressebog",
"The address book name cannot be empty." => "Adressebogens navn kan ikke være tomt.",
"Is this correct?" => "Er dette korrekt?",
"There was an unknown error when trying to delete this contact" => "Der opstod en ukendt fejl under forsøg på at slette denne kontakt",
"# groups" => "# grupper",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Nogle kontakter er markeret til sletning, men er endnu ikke slettet. Vent venligst på, at de bliver slettet.",
"Click to undo deletion of {num} contacts" => "Klik for at fortryde sletning af {num} kontakter",
"Cancelled deletion of {num}" => "Annulleret sletning af {num}",
"Contact is already in this group." => "Kontakt er allerede i denne gruppe.",
"Contacts are already in this group." => "Kontakterne er allerede i denne gruppe.",
"Couldn't get contact list." => "Kunne ikke hente kontakt liste.",
"Contact is not in this group." => "Kontakt er ikke i denne gruppe.",
"Contacts are not in this group." => "Kontakter er ikke i denne gruppe.",
"A group named {group} already exists" => "En gruppe med navnet {group} findes allerede",
"You can drag groups to\narrange them as you like." => "Du kan trække grupper til⏎ arranger dem som du vil.",
"All" => "Alle",
"Favorites" => "Foretrukne",
"Shared by {owner}" => "Delt af {owner}",
"Result: " => "Resultat:",
" imported, " => " importeret ",
" failed." => " fejl.",
"Displayname cannot be empty." => "Brugernavn må ikke være tomt.",
"Show CardDav link" => "Vis CardDav link",
"Show read-only VCF link" => "Vis skrivebeskyttet VCF link",
"Download" => "Download",
"Edit" => "Rediger",
"Delete" => "Slet",
"Cancel" => "Fortryd",
"More..." => "Mere...",
"Less..." => "Mindre...",
"You do not have the permissions to read this addressbook." => "Du har ikke rettigheder til at se denne adressebog.",
"You do not have the permissions to update this addressbook." => "Du har ikke rettigheder til at opdatere denne adressebog",
"There was an error updating the addressbook." => "Du har ikke rettigheder til at opdatere denne kontaktperson",
"You do not have the permissions to delete this addressbook." => "Du har ikke rettigheder til at slette denne adressebog",
"There was an error deleting this addressbook." => "Der opstod en fejl ved sletning af denne adressebog.",
"Jabber" => "Jabber",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "Google Talk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "Arbejde",
"Home" => "Hjemme",
"Other" => "Andet",
"Mobile" => "Mobil",
"Text" => "SMS",
"Voice" => "Telefonsvarer",
"Message" => "Besked",
"Fax" => "Fax",
"Video" => "Video",
"Pager" => "Personsøger",
"Internet" => "Internet",
"Friends" => "Venner",
"Family" => "Familie",
"There was an error deleting properties for this contact." => "Der opstod en fejl under sletning egenskaber for denne kontakt.",
"{name}'s Birthday" => "{name}s fødselsdag",
"Contact" => "Kontaktperson",
"You do not have the permissions to add contacts to this addressbook." => "Du har ikke rettigheder til at tilføje kontaktpersoner til denne adressebog",
"Could not find the vCard with ID." => "Kunne ikke finde vCard'et med ID.",
"You do not have the permissions to edit this contact." => "Du har ikke rettigheder til at redigere denne kontaktperson",
"Could not find the vCard with ID: " => "Kunne ikke finde vCard'et med ID:",
"Could not find the Addressbook with ID: " => "Kunne ikke finde adressebogen med ID.",
"You do not have the permissions to delete this contact." => "Du har ikke rettigheder til at slette denne kontaktperson",
"There was an error deleting this contact." => "Der opstod en fejl ved sletning af denne kontakt.",
"Contact not found." => "Kontakt ikke fundet",
"HomePage" => "Hjemmeside",
"New Group" => "Ny Gruppe",
"Settings" => "Indstillinger",
"Address books" => "Adressebøger",
"Import" => "Importer",
"Select files to import" => "Vælg filer, der skal importeres",
"Select files" => "Vælg filer",
"Import into:" => "Importere til:",
"OK" => "OK",
"(De-)select all" => "(Af)marker alle",
"New Contact" => "Ny Kontakt",
"Download Contact(s)" => "Hent Kontakt(er)",
"Groups" => "Grupper",
"Favorite" => "favorit",
"Delete Contact" => "Slet Kontakt",
"Close" => "Luk",
"Keyboard shortcuts" => "Tastaturgenveje",
"Navigation" => "Navigering",
"Next contact in list" => "Næste kontaktperson i listen",
"Previous contact in list" => "Forrige kontaktperson i listen",
"Expand/collapse current addressbook" => "Udvid/sammenfold nuværende adressebog",
"Next addressbook" => "Næste adressebog",
"Previous addressbook" => "Forrige adressebog",
"Actions" => "Handlinger",
"Refresh contacts list" => "Genindlæs kontaktliste",
"Add new contact" => "Tilføj ny kontaktperson",
"Add new addressbook" => "Tilføj ny adressebog",
"Delete current contact" => "Slet aktuelle kontaktperson",
"<h3>You have no contacts in your addressbook.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>" => "<h3> Du har ingen kontakter i din adressebog. </h3><p>Tilføj en ny kontakt eller importere eksisterende kontakter fra en VCF-fil.</p>",
"Add contact" => "Tilføj kontaktpeson.",
"Compose mail" => "Opret e-mail",
"Delete group" => "Slet gruppe",
"Delete current photo" => "Slet nuværende foto",
"Edit current photo" => "Rediger nuværende foto",
"Upload new photo" => "Upload nyt foto",
"Select photo from ownCloud" => "Vælg foto fra ownCloud",
"First name" => "Fornavn",
"Additional names" => "Mellemnavne",
"Last name" => "Efternavn",
"Select groups" => "Vælg grupper",
"Nickname" => "Kaldenavn",
"Enter nickname" => "Indtast kaldenavn",
"Title" => "Titel",
"Enter title" => "Enter title",
"Organization" => "Organisation",
"Enter organization" => "Enter organization",
"Birthday" => "Fødselsdag",
"Notes go here..." => "Noter her...",
"Export as VCF" => "Export as VCF",
"Add" => "Tilføj",
"Phone" => "Telefon",
"Email" => "Email",
"Instant Messaging" => "Instant Messaging",
"Address" => "Adresse",
"Note" => "Note",
"Web site" => "Hjemmeside",
"Delete contact" => "Slet kontaktperson",
"Preferred" => "Foretrukken",
"Please specify a valid email address." => "Indtast venligst en gyldig email-adresse.",
"someone@example.com" => "nogen@eksempel.com",
"Mail to address" => "Send mail til adresse",
"Delete email address" => "Slet email-adresse",
"Enter phone number" => "Indtast telefonnummer",
"Delete phone number" => "Slet telefonnummer",
"Go to web site" => "Gå til web site",
"Delete URL" => "Slet LINK",
"View on map" => "Vis på kort",
"Delete address" => "Delete address",
"1 Main Street" => "1 Hjemmeadresse",
"Street address" => "Gade",
"12345" => "12345",
"Postal code" => "Postnummer",
"Your city" => "Din by",
"City" => "By",
"Some region" => "Region",
"State or province" => "Stat eller provins",
"Your country" => "Dit land",
"Country" => "Land",
"Instant Messenger" => "Instant Messenger",
"Delete IM" => "Slet IM",
"Share" => "Del",
"Export" => "Exporter",
"CardDAV link" => "CardDAV link",
"The temporary image has been removed from cache." => "Det midlertidige billede er ikke længere tilgængeligt.",
"CardDAV syncing addresses" => "CardDAV synkroniserings adresse",
"more info" => "mere info",
"Primary address (Kontact et al)" => "Primær adresse (Kontak m. fl.)",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Adressebøger",
"New Address Book" => "Ny adressebog",
"Name" => "Navn",
"Description" => "Beskrivelse",
"Save" => "Gem"
);
